class AllHeadres:

    def set_token( self, token:str):
        self.token = token


    def header_phone_has_app(self):
    # header check_number
        header = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:144.0) Gecko/20100101 Firefox/144.0",
        "Accept": "application/json, text/plain, */*",
        "Accept-Language": "fa",
        "Accept-Encoding": "gzip, deflate, br, zstd",
        "Content-Type": "application/json",
        "Referer": "https://my.irancell.ir/invite",
        "x-app-version": "9.62.0",
        "Origin": "https://my.irancell.ir",
        "Sec-Fetch-Dest": "empty",
        "Sec-Fetch-Mode": "cors",
        "Sec-Fetch-Site": "same-origin",
        "Authorization": self.token,
        "Connection": "keep-alive",
        "Priority": "u=0",
    }
        
        return header



    def header_invite_to_MyIransell(self):
    # header invite to MyIransell
        header = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:144.0) Gecko/20100101 Firefox/144.0",
        "Accept": "application/json, text/plain, */*",
        "Accept-Language": "fa",
        "Accept-Encoding": "gzip, deflate, br, zstd",
        "Content-Type": "application/json",
        "Referer": "https://my.irancell.ir/invite/confirm",
        "x-app-version": "9.62.0",
        "Origin": "https://my.irancell.ir",
        "Sec-Fetch-Dest": "empty",
        "Sec-Fetch-Mode": "cors",
        "Sec-Fetch-Site": "same-origin",
        "Authorization": self.token,
        "Connection": "keep-alive",
        "Priority": "u=0",
        }
        
        return header



    def header_my_info(self):
        header = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:144.0) Gecko/20100101 Firefox/144.0",
        "Accept": "application/json, text/plain, */*",
        "Accept-Language": "fa",
        "Accept-Encoding": "gzip, deflate, br, zstd",
        "Referer": "https://my.irancell.ir/sim/profile",
        "x-app-version": "9.62.0",
        "Sec-Fetch-Dest": "empty",
        "Sec-Fetch-Mode": "cors",
        "Sec-Fetch-Site": "same-origin",
        "Authorization": self.token,
        "Connection": "keep-alive"
    }
    
        return header
    


    def header_View_Internet_packages(self):
        headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:144.0) Gecko/20100101 Firefox/144.0",
        "Accept": "application/json, text/plain, */*",
        "Accept-Language": "fa",
        "Accept-Encoding": "gzip, deflate, br, zstd",
        "Referer": "https://my.irancell.ir/",
        "x-app-version": "9.62.0",
        "Sec-Fetch-Dest": "empty",
        "Sec-Fetch-Mode": "cors",
        "Sec-Fetch-Site": "same-origin",
        "Authorization": self.token,
        "Connection": "keep-alive"
    }
        return headers
    

    @staticmethod
    def header_View_music_default():
        headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:144.0) Gecko/20100101 Firefox/144.0",
        "Accept": "application/json",
        "Accept-Language": "en-US,en;q=0.5",
        "Accept-Encoding": "gzip, deflate, br, zstd",
        "Referer": "https://my.irancell.ir/",
        "Origin": "https://my.irancell.ir",
        "Sec-Fetch-Dest": "empty",
        "Sec-Fetch-Mode": "cors",
        "Sec-Fetch-Site": "same-site",
        "Connection": "keep-alive"
    }
        
        return headers


    @staticmethod
    def header_Viewing_command_codes():
        headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:144.0) Gecko/20100101 Firefox/144.0",
        "Accept": "application/json",
        "Accept-Language": "en-US,en;q=0.5",
        "Accept-Encoding": "gzip, deflate, br, zstd",
        "Referer": "https://my.irancell.ir/",
        "Origin": "https://my.irancell.ir",
        "Sec-Fetch-Dest": "empty",
        "Sec-Fetch-Mode": "cors",
        "Sec-Fetch-Site": "same-site",
        "Connection": "keep-alive"
    }
        
        return headers


api_phone_has_app = "https://my.irancell.ir/api/gift/v1/refer_a_friend"


api_send_invite ="https://my.irancell.ir/api/gift/v1/refer_a_friend/notify"


api_my_info = "https://my.irancell.ir/api/sim/v1/profile"


api_View_Internet_packages = "https://my.irancell.ir/api/catalog/v2/offers"


api_View_music_default = "https://cdn-ngmy.irancell.ir/config/rbt.json"


api_Viewing_command_codes = "https://cdn-ngmy.irancell.ir/config/ussd.json"


from ..headers.header import AllHeadres
from ..methods.method import Methods
from ..apis.api import *


class Client:
    def __init__(self , token:str , platform:str="web"):
        if bool(token):
            self.token = token
            self.platform = platform
            self.methods = Methods()
            self.haedrs = AllHeadres()
            self.haedrs.set_token(self.token)


    def __str__(self):
        return f"{self.__class__.__name__}({self.token} , {self.platform})"


    def phone_has_app(self , phone:str) -> bool:
        if phone.startswith("0"):
            phone = phone[1:]
        return self.methods.phone_has_app(api=api_phone_has_app ,phone=phone , header=self.haedrs.header_phone_has_app())


    def send_invite(self, phone:str) -> dict:
        if phone.startswith("0"):
            phone = phone[1:]
        return self.methods.send_invite(api=api_send_invite ,phone=phone , header=self.haedrs.header_invite_to_MyIransell())


    def my_info(self) -> dict:
        return self.methods.my_info(api=api_my_info,header=self.haedrs.header_my_info())


    def first_name(self) -> str:
        return self.methods.first_name(api=api_my_info,header=self.haedrs.header_my_info())


    def last_name(self) -> str:
        return self.methods.last_name(api=api_my_info,header=self.haedrs.header_my_info())


    def get_email(self) -> str:
        return self.methods.get_email(api=api_my_info,header=self.haedrs.header_my_info())


    def get_address_home(self) -> str:
        return self.methods.get_address_home(api=api_my_info,header=self.haedrs.header_my_info())


    def activation_date(self) -> str:
        return self.methods.activation_date(api=api_my_info,header=self.haedrs.header_my_info())


    def get_phone_home(self) -> str:
        return self.methods.get_phone_home(api=api_my_info,header=self.haedrs.header_my_info())


    def sim_card_serial_number(self) -> str:
        return self.methods.sim_card_serial_number(api=api_my_info,header=self.haedrs.header_my_info())


    def state_simcard(self) -> str:
        return self.methods.state_simcard(api=api_my_info,header=self.haedrs.header_my_info())


    def View_Internet_packages(self) -> dict:
        return self.methods.View_Internet_packages(api=api_View_Internet_packages,header=self.haedrs.header_View_Internet_packages())


    def View_music_default(self) -> dict:
        return self.methods.View_music_default(api=api_View_music_default,header=self.haedrs.header_View_music_default())


    def Viewing_command_codes(self) -> dict:
        return self.methods.Viewing_command_codes(api=api_Viewing_command_codes,header=self.haedrs.header_Viewing_command_codes())


from .client.client import Client

"""
MIT License

Copyright (c) 2025 [Danial Erfan Dost]

Permission is hereby granted, free of charge, to any person obtaining a copy
of this book and associated documentation files (the "Book"), to deal
in the Book without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Book, and to permit persons to whom the Book is furnished to do so,
subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Book.

THE BOOK IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE BOOK OR THE USE OR OTHER DEALINGS IN THE BOOK.
"""

__version__ = "1.0.0"
__author__ = "Danial Erfan Dost"
__github__ = "https://github.com/NOMASKERFAN"
print(__author__)
print(__github__)


import requests
import json

class Methods:
    
    def phone_has_app(self ,api:str , phone:str , header:dict) ->bool:
        
        data = {
        "application_name": "NGMI",
        "friend_number": "98"+phone
        }
        respance = requests.post(url=api , json=data , headers=header)
        if respance.status_code == 200 and json.loads(respance.text)['message'] == "done":
            return False
        return True



    def send_invite(self,api:str, phone: str , header:dict) ->dict:
        data = {
        "application_name": "NGMI",
        "friend_number": "98"+phone
        }
        respance = requests.post(url=api , json=data , headers=header)
        if respance.status_code == 200:
            return json.loads(respance.text)



    def my_info(self ,api:str, header:dict) ->dict:
        respance = requests.get(url=api , headers=header)
        if respance.status_code == 200:
            return json.loads(respance.text)


    def first_name(self,api:str, header:dict) ->str:
        respance = self.my_info(api=api,header=header)
        return respance["first_name"]


    def last_name(self ,api:str, header:dict) ->str:
        respance = self.my_info(api=api,header=header)
        return respance["last_name"]


    def get_email(self,api:str, header:dict) ->str:
        respance = self.my_info(api=api,header=header)
        return respance["email"]


    def get_address_home(self,api:str, header:dict) ->str:
        respance = self.my_info(api=api,header=header)
        return respance["address"]


    def activation_date(self,api:str, header:dict) ->str:
        respance = self.my_info(api=api,header=header)
        return respance["activation_date"]


    def get_phone_home(self,api:str, header:dict) ->str:
        respance = self.my_info(api=api,header=header)
        return respance["contact_number"]


    def sim_card_serial_number(self,api:str, header:dict) ->str:
        respance = self.my_info(api=api,header=header)
        return respance["kit_number"]


    def state_simcard(self,api:str, header:dict) ->str:
        respance = self.my_info(api=api,header=header)
        return respance["operation_status"]


    def View_Internet_packages(self,api:str, header:dict) ->dict:
        params = {
        "type": "data",
        "category": "normal"
        }
        respance = requests.get(url=api, headers=header , params=params)
        if respance.status_code == 200:
            return json.loads(respance.text)
    


    def View_music_default(self,api:str, header:dict) ->dict:
        params = {
        "v": "20250831171938970372"
        }
        respance = requests.get(url=api , headers=header , params=params)
        if respance.status_code == 200:
            return json.loads(respance.text)



    def off_sim_card(self) -> bool:
        """غیرفعال کردن سیم‌کارت (اگر ممکن است). برمی‌گرداند True در صورت موفقیت."""


    def get_device(self) -> dict:
        """اطلاعات دستگاه (مدل، OS، آخرین لاگین و...) به صورت دیکشنری."""



    def Viewing_command_codes(self,api:str, header:dict) ->dict:
        params = {
            "v": "20250203124237193931"
            }
        respance = requests.get("https://cdn-ngmy.irancell.ir/config/ussd.json" , headers=header , params=params)
        if respance.status_code == 200:
            return json.loads(respance.text)